from distutils.core import setup

setup(
    name='gcmtools',
    version='0.4.5',
    packages=['gcmtools',],
    author='Adiv Paradise',
    author_email='paradise.astro@gmail.com',
    license='GNU General Public License',
    url='https://github.com/alphaparrot/gcmtools',
    description='GCM Output Analysis Tools',
    long_description=open('README.txt').read(),
    )